@@ -170,17 +170,17 @@ histBxp <-
   ##						calls  p.hboxp(.) !
 
   ## determine the height of the plot
-  if(missing(breaks)){
-    if(missing(nclass))
-      h <- hist(x, probability = probability, include.lowest = include.lowest,
-		plot = FALSE)
+  h <-
+    if(missing(breaks)){
+      if(missing(nclass))
+        hist(x, include.lowest = include.lowest, plot = FALSE)
       else
-	h <- hist(x, nclass = nclass, probability = probability,
-		  include.lowest = include.lowest, plot = FALSE)
-  }
+	hist(x, nclass = nclass,
+             include.lowest = include.lowest, plot = FALSE)
+    }
     else
-      h <- hist(x, breaks = breaks, probability = probability,
-		include.lowest = include.lowest, plot = FALSE)
+        hist(x, breaks = breaks,
+             include.lowest = include.lowest, plot = FALSE)
   ymax <- max(h$counts)
   ymin <-  - ymax * width # range:  (-w,1)*ymax  instead of  (0,1)*ymax
 
@@ -336,12 +336,12 @@ polyn.eval <- function(coef, x)
 
 ## negative x .. may make sense in some cases,.... but not yet :
 ##digitsBase <- function(x, base = 2, ndigits = 1 + floor(log(max(abs(x)),base)))
-digitsBase <- function(x, base = 2, ndigits = 1 + floor(1e-9+ log(max(x),base)))
+digitsBase <- function(x, base = 2, ndigits = 1 + floor(1e-9 + log(max(x,1), base)))
 {
     ## Purpose: Give the vector A of the base-_base_ representation of _n_:
     ## -------  n = sum_{k=0}^M  A_{M-k} base ^ k ,   where  M = length(a) - 1
     ## Value: MATRIX  M where  M[,i]  corresponds to  x[i]
-    ## Author: Martin Maechler, Date:  Wed Dec  4 14:10:27 1991
+    ## Author: Martin Maechler, Date: Dec 4, 1991
     ## ----------------------------------------------------------------
     ## ---->  help(digitsBase) !
     ## ------------------------------
@@ -490,6 +490,21 @@ uniqueL <- function(x, isuniq = !duplicated(x), need.sort = is.unsorted(x))
 }
 
 
+##' Constructor of a "list" (really an environment) of functions (and more)
+##' which all *share* the same environment in which they exist
+##' --> ../man/funEnv.Rd
+##'  	~~~~~~~~~~~~~~~~
+funEnv <- function(..., envir = NULL, parent = parent.frame(),
+                   hash = (...length() > 100), size = max(29L, ...length())) {
+    e <- list2env(list(...), envir=envir, parent=parent, hash=hash, size=size)
+    for(n in names(e)) ## iff function or formula, set environment to 'e':
+	if(is.function(e[[n]]) || (is.call(e[[n]]) &&
+				   inherits(e[[n]], "formula")))
+	    environment(e[[n]]) <- e
+    e
+}
+
+
 is.whole <- function(x, tolerance = sqrt(.Machine$double.eps))
 {
     ## Tests if a numeric scalar (or vector, matrix or array) is a whole
@@ -656,10 +671,7 @@ seqXtend <- function(x, length., method = c("simple","aim","interpolate"),
                     from = NULL, to = NULL)
 {
   ## Purpose: produce a seq(.) covering the range of 'x' and INCLUDING x
-  ## ----------------------------------------------------------------------
-  ## Arguments:
-  ## ----------------------------------------------------------------------
-  ## Author: Martin Maechler, Date: 28 Nov 2007, 11:09
+  ## Author: Martin Maechler, Date: 28 Nov 2007 =======> ../man/seqXtend.Rd
     x <- unique(sort(x))
     n <- length(x)
     method <- match.arg(method)
@@ -690,8 +702,9 @@ seqXtend <- function(x, length., method = c("simple","aim","interpolate"),
             ## now "round" the k1[] such that sum(.) remains == nn
             k <- roundfixS(k1) ## keep the right border, drop the left
             seqI <- function(i) seq(x[i], x[i+1], length.out=k[i]+2)[-1]
-            c(x[1], unlist(lapply(1:(n-1), seqI)))
-
+            l.seq <- lapply(1:(n-1), seqI)
+            ## do.call(c, *), e.g. for new (R-devel 4.1.x) c.Date() [KH]:
+            c(x[1], if(is.object(x)) do.call(c, l.seq) else unlist(l.seq))
         } else {
             nn <- switch(method, "simple" = length.,
                          "aim" = length. - n + from_is1 + from_isL)
@@ -775,7 +788,7 @@ diagX <- function(n)
   ## Arguments: n: integer dimension of matrix
   ## ----------------------------------------------------------------
     m <- numeric(n * n)
-    m[1+ (n-1)* (1:n)] <- 1
+    m[1L+ (n-1L)* seq_len(n)] <- 1
     dim(m) <- c(n,n)
     m
 }
@@ -991,7 +1004,9 @@ prt.DEBUG <- function(..., LEVEL = 1) {
 
 ##' @title Read an Emacs Org Table by read.table()
 ## --> ../man/read.org.table.Rd
-read.org.table <- function(file, header = TRUE, skip = 0, fileEncoding = "", text, ...) {
+read.org.table <- function(file, header = TRUE, skip = 0,
+                           encoding = "native", fileEncoding = "",
+                           text, ...) {
     ## file - text   handling --- cut'n'paste from read.table()'s header
     if (missing(file) && !missing(text)) {
 	file <- textConnection(text, encoding = "UTF-8")
@@ -1008,14 +1023,11 @@ read.org.table <- function(file, header = TRUE, skip = 0, fileEncoding = "", tex
         open(file, "rt")
         on.exit(close(file))
     }
-    if("encoding" %in% names(list(...)))
-       warning("'encoding' does not make sense here")
-
     if(skip > 0L) readLines(file, skip)
-    ll <- readLines(file)
+    ll <- readLines(file, encoding=encoding)
     close(file); on.exit()
     ## drop |--------+---------+--------+--|  :
-    if(any(i <- grep("---+\\+--", ll[1:3]))) ll <- ll[-i]
+    if(length(i <- grep("---+\\+--", ll[1:3]))) ll <- ll[-i]
     ## drop beginning and ending "|" :
     ll <- sub("^ *\\|", "",
               sub("\\| *$", "", ll))
@@ -1030,8 +1042,8 @@ read.org.table <- function(file, header = TRUE, skip = 0, fileEncoding = "", tex
     }
     ## drop empty lines at end only
     while(grepl("^ *$", tail(ll, 1L))) ll <- ll[-length(ll)]
-    f.ll <- textConnection(ll, encoding = "UTF-8")
+    f.ll <- textConnection(ll)# , encoding = "UTF-8"  is *NOT* good
     on.exit(close(f.ll))
     read.table(f.ll, header=FALSE, sep = "|",
-               col.names = col.names, encoding = "UTF-8", ...)
+               col.names = col.names, ...) # , encoding = "UTF-8" *not* good
 }
